==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Плагин %1 не совместим с системой.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Настройки Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Включить</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Настройки Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 подключено</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Подключение...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Выключен</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Добавить раскладку клавиатуры</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Дата и время</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-часовой формат времени</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-часовой формат времени</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Настройки времени</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Включить сеть</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Отключить сеть</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Настройки сети</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Вы уверены, что хотите очистить %1 объектов?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Это действие необратимо</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Неизвестное устройство</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Неизвестный объем</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Отмонтировать все</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Выбор Программ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Современный Режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Эффективный Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Снизу</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Отображать Всегда</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Держать Скрытым</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Умное Скрытие</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Расположение</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Плагины</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Многозадачный Вид</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Открепить</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Отключить проводное соединение</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Включить проводное соединение</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Отключить проводное соединение</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Включить проводное соединение</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Отключить сеть</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Включить сеть</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Настройки сети</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Устройство отключено</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Беспроводное соединение: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Проводное подключение к: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не подключено</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Подключено, без доступа к Интернету</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Сетевой кабель отключен</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Беспроводная Сеть</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Проводная Сеть</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Ошибка подключения</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Проводная Сеть</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Проводная Сеть %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Экранная Клавиатура</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Питание</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Параметры питания</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Емкость %1, %2 мин. осталось</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Емкость %1, %2 час. %3 мин. осталось</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Зарядка %1, %2 мин. до полной зарядки</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Зарядка %1, %2 час. %3 мин. до полной зарядки</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Заряжен</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Объем %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Заряжается %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Заряд %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Заряд %1, полностью заряжен</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Показать Рабочий стол</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Открепить</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Питание</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Спящий Режим</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Блокировать</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Сменить пользователя</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Параметры питания</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Устройство</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Включить звук</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Приглушить</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Настройки звука</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Громкость %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Корзина</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Корзина - %1 файл</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Корзина - %1 файлов</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Очистить</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Системный Лоток</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Беспроводная Сеть</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Беспроводная Сеть %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.1.orig.tar.xz: dde-dock-5.5.38.1/translations/dde-dock_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Плагин %1 не совместим с системой.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Включить</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Настройки Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Включить</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Настройки Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 подключено</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Подключение...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Выключен</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Добавить раскладку клавиатуры</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Дата и время</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-часовой формат времени</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-часовой формат времени</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Настройки времени</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Вы уверены, что хотите очистить %1 объектов?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Это действие необратимо</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Неизвестное устройство</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Неизвестный объем</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Отмонтировать все</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Выбор Программ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Выйти из Безопасного Режима</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Dock - Безопасный Режим</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Dock находится в безопасном режиме, пожалуйста, выйдите, чтобы показать ее нормально</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Современный Режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Эффективный Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Снизу</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Отображать Всегда</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Держать Скрытым</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Умное Скрытие</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Расположение</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Несколько Дисплеев</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Область Плагина</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Выбрать значки появляющиеся в Dock</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Стильный режим</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Эффективный режим</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>На верху</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Слева
</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Расположение</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Отображать</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Скрывать</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Умное скрытие</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Маленький</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Большой</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Показывать Dock</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>На экране, где располагается курсор</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Только на главном экране</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Многозадачный Вид</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Открепить</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Экранная Клавиатура</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Питание</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Параметры питания</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Емкость %1, %2 мин. осталось</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Емкость %1, %2 час. %3 мин. осталось</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Зарядка %1, %2 мин. до полной зарядки</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Зарядка %1, %2 час. %3 мин. до полной зарядки</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Объем %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Заряжается %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Заряд %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Заряд %1, полностью заряжен</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dock</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Показать Рабочий стол</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Открепить</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Питание</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Спящий Режим</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Блокировать</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Сменить пользователя</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Параметры питания</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Устройство</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Включить звук</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Приглушить</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Настройки звука</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Громкость %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Корзина</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Корзина - %1 файл</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Корзина - %1 файлов</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Удалить в корзину</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Очистить</translation>
    </message>
</context>
</TS>
